<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="el">
<context>
    <name>DefaultModel</name>
    <message>
        <location filename="../default_model.cpp" line="51"/>
        <source>Command</source>
        <translation>Εντολή</translation>
    </message>
    <message>
        <location filename="../default_model.cpp" line="52"/>
        <source>DBus call</source>
        <translation>Κλήση DBus</translation>
    </message>
    <message>
        <location filename="../default_model.cpp" line="53"/>
        <source>Client</source>
        <translation>Πελάτης</translation>
    </message>
    <message>
        <location filename="../default_model.cpp" line="143"/>
        <source>Id</source>
        <translation>Αναγνωριστικό</translation>
    </message>
    <message>
        <location filename="../default_model.cpp" line="146"/>
        <source>Shortcut</source>
        <translation>Συντόμευση</translation>
    </message>
    <message>
        <location filename="../default_model.cpp" line="149"/>
        <source>Description</source>
        <translation>Περιγραφή</translation>
    </message>
    <message>
        <location filename="../default_model.cpp" line="152"/>
        <source>Type</source>
        <translation>Τύπος</translation>
    </message>
    <message>
        <location filename="../default_model.cpp" line="155"/>
        <source>Info</source>
        <translation>Πληροφορίες</translation>
    </message>
</context>
<context>
    <name>EditActionDialog</name>
    <message>
        <location filename="../edit_action_dialog.ui" line="14"/>
        <source>Edit Action</source>
        <translation>Επεξεργασία της ενέργειας</translation>
    </message>
    <message>
        <location filename="../edit_action_dialog.ui" line="31"/>
        <source>&amp;Shortcut:</source>
        <translation>&amp;Συντόμευση:</translation>
    </message>
    <message>
        <location filename="../edit_action_dialog.ui" line="74"/>
        <source>&amp;Description:</source>
        <translation>&amp;Περιγραφή:</translation>
    </message>
    <message>
        <location filename="../edit_action_dialog.ui" line="87"/>
        <source>&amp;Enabled</source>
        <translation>&amp;Ενεργοποιημένο</translation>
    </message>
    <message>
        <location filename="../edit_action_dialog.ui" line="102"/>
        <source>&amp;Command</source>
        <translation>&amp;Εντολή</translation>
    </message>
    <message>
        <location filename="../edit_action_dialog.ui" line="109"/>
        <source>&amp;DBus message</source>
        <translation>Μήνυμα &amp;DBus</translation>
    </message>
    <message>
        <location filename="../edit_action_dialog.ui" line="118"/>
        <source>Type:</source>
        <translation>Τύπος:</translation>
    </message>
    <message>
        <location filename="../edit_action_dialog.ui" line="164"/>
        <source>Co&amp;mmand:</source>
        <translation>Ε&amp;ντολή:</translation>
    </message>
    <message>
        <location filename="../edit_action_dialog.ui" line="206"/>
        <source>S&amp;ervice:</source>
        <translation>&amp;Υπηρεσία:</translation>
    </message>
    <message>
        <location filename="../edit_action_dialog.ui" line="219"/>
        <source>&amp;Path:</source>
        <translation>&amp;Διαδρομή:</translation>
    </message>
    <message>
        <location filename="../edit_action_dialog.ui" line="232"/>
        <source>&amp;Interface:</source>
        <translation>&amp;Διεπαφή:</translation>
    </message>
    <message>
        <location filename="../edit_action_dialog.ui" line="245"/>
        <source>&amp;Method:</source>
        <translation>&amp;Μέθοδος:</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../main_window.ui" line="14"/>
        <source>Global Actions Manager</source>
        <translation>Διαχειριστής καθολικών ενεργειών</translation>
    </message>
    <message>
        <location filename="../main_window.ui" line="27"/>
        <source>Search</source>
        <translation>Αναζήτηση</translation>
    </message>
    <message>
        <location filename="../main_window.ui" line="72"/>
        <source>Add ...</source>
        <translation>Προσθήκη ...</translation>
    </message>
    <message>
        <location filename="../main_window.ui" line="82"/>
        <source>Remove</source>
        <translation>Αφαίρεση</translation>
    </message>
    <message>
        <location filename="../main_window.ui" line="92"/>
        <source>Modify ...</source>
        <translation>Τροποποίηση ...</translation>
    </message>
    <message>
        <location filename="../main_window.ui" line="109"/>
        <source>Swap</source>
        <translation>Εναλλαγή</translation>
    </message>
    <message>
        <location filename="../main_window.ui" line="135"/>
        <source>Multiple actions behaviour:</source>
        <translation>Συμπεριφορά πολλαπλών ενεργειών:</translation>
    </message>
    <message>
        <location filename="../main_window.ui" line="143"/>
        <source>First</source>
        <comment>globalkeys/config/multipleActions</comment>
        <translation>Πρώτη</translation>
    </message>
    <message>
        <location filename="../main_window.ui" line="148"/>
        <source>Last</source>
        <comment>globalkeys/config/multipleActions</comment>
        <translation>Τελευταία</translation>
    </message>
    <message>
        <location filename="../main_window.ui" line="153"/>
        <source>None</source>
        <comment>globalkeys/config/multipleActions</comment>
        <translation>Ουδεμία</translation>
    </message>
    <message>
        <location filename="../main_window.ui" line="158"/>
        <source>All</source>
        <comment>globalkeys/config/multipleActions</comment>
        <translation>Όλες</translation>
    </message>
    <message>
        <location filename="../main_window.ui" line="183"/>
        <source>Default</source>
        <translation>Εξ ορισμού</translation>
    </message>
    <message>
        <location filename="../main_window.ui" line="207"/>
        <source>Close</source>
        <translation>Κλείσιμο</translation>
    </message>
    <message>
        <location filename="../main_window.cpp" line="191"/>
        <source>Restore Default</source>
        <translation>Επαναφορά προκαθορισμένων</translation>
    </message>
    <message>
        <location filename="../main_window.cpp" line="192"/>
        <source>Your defined shortcuts will be removed.
Do you want to proceed?</source>
        <translation>Οι συντομεύσεις που έχετε καθορίσει θα διαγραφούν.
Θέλετε να συνεχίσετε;</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../main.cpp" line="51"/>
        <source>Platform Unsupported</source>
        <translation>Μη υποστηριζόμενο πλατύβαθρο</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="52"/>
        <source>LXQt globalkeys are currently unsupported under Wayland.

Global shortcuts can be configured in the settings of the compositor instead.</source>
        <translation>Οι καθολικές συντομεύσεις LXQt δεν υποστηρίζονται στο Wayland.

Αντί αυτού, μπορούν να διαμορφωθούν από τις ρυθμίσεις του.</translation>
    </message>
</context>
</TS>
